pub enum MatchHookKind {
Mark,
Accept,
Discard,
Annotate,
}Expand description
Capability class for a match hook decision.
Variants
Mark
Observe and emit diagnostics without changing acceptance.
Accept
Optionally turn a rejected match into an accepted one.
Discard
Optionally turn an accepted match into a rejected one.
Annotate
Add annotations such as score deltas and diagnostics.