pub enum ShapeQueryRelation {
Subsumes,
SubshapeOf,
Overlaps,
}Expand description
Direction used when matching a candidate Shape against a requested Shape.
Variants
Subsumes
The candidate accepts every value accepted by the requested Shape.
SubshapeOf
The candidate is contained by the requested Shape.
Overlaps
The candidate and requested Shapes have at least one known value in common.