pub enum ShapeRelationKind {
Equal,
LeftSubshape,
RightSubshape,
Overlap,
Disjoint,
Unknown,
}Expand description
Relation categories reported by ShapeRelation.
Variants
Equal
Both shapes imply each other.
LeftSubshape
The left shape is known to be a subshape of the right shape.
RightSubshape
The right shape is known to be a subshape of the left shape.
Overlap
At least one probe is accepted by both shapes.
Disjoint
The shapes are conservatively known to have no common values.
Unknown
The runtime could not prove a stronger relation.