pub fn case_result_shape(case: &FunctionCase) -> Option<&dyn Shape>Expand description
Borrow the result shape of a case, if it declares one.
pub fn case_result_shape(case: &FunctionCase) -> Option<&dyn Shape>Borrow the result shape of a case, if it declares one.