pub fn normalize_shape(
cx: &mut Cx,
shape: &dyn Shape,
) -> Result<ShapeNormalForm>Expand description
Build the conservative comparison normal form for a shape.
pub fn normalize_shape(
cx: &mut Cx,
shape: &dyn Shape,
) -> Result<ShapeNormalForm>Build the conservative comparison normal form for a shape.