pub fn shape_grammar(
shape: &dyn Shape,
target: GrammarTarget,
renderer: &dyn GrammarRenderer,
) -> Result<ShapeGrammar>Expand description
Lowers shape and renders it through a supplied codec-owned renderer.
pub fn shape_grammar(
shape: &dyn Shape,
target: GrammarTarget,
renderer: &dyn GrammarRenderer,
) -> Result<ShapeGrammar>Lowers shape and renders it through a supplied codec-owned renderer.