pub struct BrowseSignature { /* private fields */ }Expand description
A callable decorated with argument and result Shapes used only by browsers.
Construction fails closed when callable is not callable or either
metadata value does not expose the Shape protocol. Invocation never reads
the metadata and therefore cannot check, coerce, rank, or select calls.
Implementations