OptionFieldSpec

Struct OptionFieldSpec 

pub struct OptionFieldSpec {
    pub key: Symbol,
    pub shape: Arc<dyn Shape>,
    pub required: bool,
}
One option field constraint for check_option_map.

Fields

key: Symbol

Symbol key to look up in the option map.

shape: Arc<dyn Shape>

Shape that must accept the option value when present.

required: bool

Whether this option must be present.

Implementations

Source

impl OptionFieldSpec

pub fn required(key: Symbol, shape: Arc<dyn Shape>) -> Self

Build a required option field.

pub fn optional(key: Symbol, shape: Arc<dyn Shape>) -> Self

Build an optional option field.