pub struct ShapeNormalForm {
pub kind: ShapeNormalKind,
pub label: String,
}Expand description
Structural summary used by conservative shape comparison.
Normal forms expose enough algebraic structure for relation checks without
adding a closed kind enum to the kernel Shape trait.
Fields
kind: ShapeNormalKindNormalized structural kind.
label: StringHuman-readable label from the source shape description.