pub struct TableFieldSpec {
pub key: Symbol,
pub shape: Arc<dyn Shape>,
pub required: bool,
}Expand description
One field constraint inside a TableShape.
Fields
key: SymbolSymbol key to look up in the table or map expression.
shape: Arc<dyn Shape>Shape that must accept the field value or expression.
required: boolWhether the field must be present.