pub struct TableShape { /* private fields */ }Expand description
Shape for table values or map expressions with named field constraints.
Required fields must be present and accepted by their field shapes. Extra
fields are controlled by TableExtraPolicy.
let shape = TableShape::single(
Symbol::new("ok"),
Arc::new(ExprKindShape::new(ExprKind::Bool)),
);
let expr = Expr::Map(vec![(Expr::Symbol(Symbol::new("ok")), Expr::Bool(true))]);
assert!(shape.check_expr(&mut cx, &expr).unwrap().accepted);Implementations
Sourceimpl TableShape
impl TableShape
Sourcepub fn single(key: Symbol, shape: Arc<dyn Shape>) -> Self
pub fn single(key: Symbol, shape: Arc<dyn Shape>) -> Self
Build a table shape requiring a single named field, allowing extras.
Sourcepub fn new(fields: Vec<TableFieldSpec>, extra: TableExtraPolicy) -> Self
pub fn new(fields: Vec<TableFieldSpec>, extra: TableExtraPolicy) -> Self
Build a table shape from explicit field specs and an extra-key policy.
Sourcepub fn fields(&self) -> &[TableFieldSpec]
pub fn fields(&self) -> &[TableFieldSpec]
Return the field constraints in declaration order.
Sourcepub fn extra(&self) -> &TableExtraPolicy
pub fn extra(&self) -> &TableExtraPolicy
Return the policy applied to keys not listed in the field specs.