pub struct VennShapeSet { /* private fields */ }Expand description
Named set of shapes used to build Venn-style regions.
VennShapeSet is a runtime object so Lisp helpers can create it once and
then request union, intersection, selected-only, outside, or exactly regions.
Implementations
Sourceimpl VennShapeSet
impl VennShapeSet
Sourcepub fn new(members: Vec<(Symbol, Arc<dyn Shape>)>) -> Self
pub fn new(members: Vec<(Symbol, Arc<dyn Shape>)>) -> Self
Create a named Venn set from shape members.
Sourcepub fn members(&self) -> &[(Symbol, Arc<dyn Shape>)]
pub fn members(&self) -> &[(Symbol, Arc<dyn Shape>)]
Return the named members in registration order.
Sourcepub fn intersection(&self) -> Arc<dyn Shape>
pub fn intersection(&self) -> Arc<dyn Shape>
Build a shape accepted by every member.
Sourcepub fn only(&self, name: &Symbol) -> Result<Arc<dyn Shape>>
pub fn only(&self, name: &Symbol) -> Result<Arc<dyn Shape>>
Build a shape accepted by one named member and rejected by the others.
Sourcepub fn outside_all(&self) -> Arc<dyn Shape>
pub fn outside_all(&self) -> Arc<dyn Shape>
Build a shape rejected by the union of all members.