pub struct OptionFieldSpec {
pub key: Symbol,
pub shape: Arc<dyn Shape>,
pub required: bool,
}Expand description
One option field constraint for check_option_map.
Fields
key: SymbolSymbol key to look up in the option map.
shape: Arc<dyn Shape>Shape that must accept the option value when present.
required: boolWhether this option must be present.
Implementations